@@ -1,7 +1,7 @@
 import random
 import re
 import json
-
+import os
 import requests
 from tqdm.auto import tqdm
 from sentence_splitter import SentenceSplitter, split_text_into_sentences
@@ -9,9 +9,14 @@ from .diff import dff_text
 from .text_tilling import auto_text_tilling
 from .cut import auto_cut_markdown
 import  logging
-
+import time
 from .img import get_markdown_images,get_markdown_images_format
-
+def check_loadavg(limit=30):
+    avg=os.getloadavg()
+    if avg[0]<limit:
+        return True
+    else:
+        return False
 def auto_request(payload, api, timeout=600):
     """
 
@@ -164,6 +169,9 @@ class AutoReWrite(object):
         :param text:
         :return:
         """
+        while check_loadavg(limit=30)==False:
+            time.sleep(100)
+
         mi=max(int(len(text.split(" "))*0.6),64)
         # payload = {"config": {
         #     "do_sample": auto_sample,
